Package: interpretCI
Type: Package
Title: Estimate the Confidence Interval and Interpret Step by Step
Version: 0.1.1
Authors@R: person("Keon-Woong","Moon", email="cardiomoon@gmail.com",
    role=c("aut", "cre"))
URL: https://github.com/cardiomoon/interpretCI,
        https://cardiomoon.github.io/interpretCI/
Description: Estimate confidence intervals for mean, proportion, mean difference 
   for unpaired and paired samples and proportion difference. Plot the confidence 
   intervals. Generate documents explaining the statistical result step by step.
License: GPL-3
Encoding: UTF-8
Imports: dplyr, purrr, tidyr, rlang, ggplot2, scales, ggbeeswarm,
        patchwork, aplot, rstudioapi, rmarkdown, flextable, officer,
        english, RColorBrewer, moonBook
Suggests: knitr, PairedData, glue
RoxygenNote: 7.1.2
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2022-01-28 01:32:50 UTC; cardiomoon
Author: Keon-Woong Moon [aut, cre]
Maintainer: Keon-Woong Moon <cardiomoon@gmail.com>
Repository: CRAN
Date/Publication: 2022-01-28 08:50:02 UTC
Built: R 4.6.0; ; 2026-04-25 13:44:24 UTC; unix
