# Generated by roxygen2: do not edit by hand

S3method(meanCI,data.frame)
S3method(meanCI,default)
S3method(plot,meanCI)
S3method(print,meanCI)
S3method(print,plotCI)
export("%>%")
export(English)
export(acs)
export(draw_n)
export(draw_t)
export(english2)
export(estimationPlot1)
export(interpret)
export(is.mynumeric)
export(isProvided)
export(meanCI)
export(meanCI2)
export(meanCI2df)
export(meanCI2df1)
export(meanCI_sub)
export(meanCIplot1)
export(pairPlot)
export(pairPlot1)
export(palette2colors)
export(propCI)
export(propCI_sub)
export(rstudio_viewer)
export(select)
export(show_t_table)
export(show_z_table)
export(textBox)
import(utils)
importFrom(RColorBrewer,brewer.pal)
importFrom(RColorBrewer,brewer.pal.info)
importFrom(aplot,xrange)
importFrom(aplot,ylim2)
importFrom(aplot,yrange)
importFrom(dplyr,`%>%`)
importFrom(dplyr,all_of)
importFrom(dplyr,arrange)
importFrom(dplyr,as_tibble)
importFrom(dplyr,count)
importFrom(dplyr,everything)
importFrom(dplyr,filter)
importFrom(dplyr,mutate)
importFrom(dplyr,near)
importFrom(dplyr,rename)
importFrom(dplyr,select)
importFrom(english,english)
importFrom(flextable,align)
importFrom(flextable,autofit)
importFrom(flextable,bg)
importFrom(flextable,bold)
importFrom(flextable,border_outer)
importFrom(flextable,color)
importFrom(flextable,delete_part)
importFrom(flextable,flextable)
importFrom(flextable,font)
importFrom(flextable,fontsize)
importFrom(flextable,highlight)
importFrom(flextable,italic)
importFrom(flextable,line_spacing)
importFrom(flextable,width)
importFrom(ggbeeswarm,geom_quasirandom)
importFrom(ggplot2,aes)
importFrom(ggplot2,aes_string)
importFrom(ggplot2,annotate)
importFrom(ggplot2,element_blank)
importFrom(ggplot2,element_text)
importFrom(ggplot2,expand_limits)
importFrom(ggplot2,geom_area)
importFrom(ggplot2,geom_hline)
importFrom(ggplot2,geom_line)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_polygon)
importFrom(ggplot2,geom_segment)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,ggplot_build)
importFrom(ggplot2,guides)
importFrom(ggplot2,labs)
importFrom(ggplot2,scale_color_brewer)
importFrom(ggplot2,scale_x_continuous)
importFrom(ggplot2,scale_x_discrete)
importFrom(ggplot2,scale_y_continuous)
importFrom(ggplot2,sec_axis)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_classic)
importFrom(grid,arrow)
importFrom(grid,unit)
importFrom(officer,fp_border)
importFrom(patchwork,plot_layout)
importFrom(purrr,map2_dfc)
importFrom(purrr,map2_dfr)
importFrom(purrr,map_dfc)
importFrom(purrr,map_dfr)
importFrom(rlang,.data)
importFrom(rlang,enexpr)
importFrom(rmarkdown,render)
importFrom(rstudioapi,viewer)
importFrom(scales,hue_pal)
importFrom(stats,dnorm)
importFrom(stats,dt)
importFrom(stats,na.omit)
importFrom(stats,pnorm)
importFrom(stats,pt)
importFrom(stats,qnorm)
importFrom(stats,qt)
importFrom(stats,rnorm)
importFrom(stats,sd)
importFrom(tidyr,pivot_longer)
